@@ -2,7 +2,7 @@ package HTML::Lint::Pluggable;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use parent qw/ HTML::Lint /;
 
@@ -46,10 +46,11 @@ sub override {
     my ($self, $method, $code) = @_;
     my $class = ref($self) or croak('this method can called by instance only.');
 
-    {
-        my $override_code = $code->($class->can($method));
+    my $override_code = $code->($class->can($method));
 
-        no strict 'refs';
+    {
+        no strict   'refs'; ## no critic
+        no warnings 'redefine';
         *{"${class}::${method}"} = $override_code;
     }
 }
@@ -63,7 +64,7 @@ HTML::Lint::Pluggable - plugin system for HTML::Lint
 
 =head1 VERSION
 
-This document describes HTML::Lint::Pluggable version 0.02.
+This document describes HTML::Lint::Pluggable version 0.03.
 
 =head1 SYNOPSIS
 
